<?php
/*
Plugin Name: LINE/電話クリックトラッカー
Description: LINE追加ボタンと電話番号リンクのクリックをトラッキングし、GA4へ各イベント (line_click_plugin / tel_click_plugin) を送信します。<br>
ログには地域（市町村）も記録し、ログ一覧ではフィルタ機能と個別・選択削除が可能です。<br>
管理画面でLINE・電話ボタンのデザイン（テキストのみ or ボタン形式／背景色、文字色、フォントサイズ、角丸、シャドウ、フォントファミリー、ボタンテキスト、LINE登録URL）および通知メールアドレスを設定できます。<br>
制作者: Sakamoto
Version: 1.10
Author: Sakamoto
*/

global $line_click_tracker_db_version;
$line_click_tracker_db_version = '1.10';

/* ===== DBテーブル作成／削除 ===== */
function line_click_tracker_install() {
    global $wpdb, $line_click_tracker_db_version;
    $table_name = $wpdb->prefix . 'line_click_logs';
    $charset_collate = $wpdb->get_charset_collate();
    $sql = "CREATE TABLE IF NOT EXISTS $table_name (
      id mediumint(9) NOT NULL AUTO_INCREMENT,
      click_time datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
      click_type varchar(20) NOT NULL DEFAULT 'line',
      page_url text NOT NULL,
      referrer text,
      ip_address varchar(100) NOT NULL,
      region varchar(100) NOT NULL DEFAULT '',
      user_agent text,
      device varchar(20),
      visit_count int,
      visit_history text,
      PRIMARY KEY  (id)
    ) $charset_collate;";
    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    dbDelta($sql);
    add_option('line_click_tracker_db_version', $line_click_tracker_db_version);
}
register_activation_hook(__FILE__, 'line_click_tracker_install');

function line_click_tracker_uninstall() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'line_click_logs';
    $sql = "DROP TABLE IF EXISTS $table_name;";
    $wpdb->query($sql);
}
register_deactivation_hook(__FILE__, 'line_click_tracker_uninstall');

/* ===== 管理画面メニュー ===== */
function line_click_tracker_admin_menu() {
    add_menu_page('クリックトラッカー', 'クリックトラッカー', 'manage_options', 'line-click-tracker', 'line_click_tracker_settings_page');
    add_submenu_page('line-click-tracker', 'ログ一覧', 'ログ一覧', 'manage_options', 'line-click-tracker-logs', 'line_click_tracker_logs_page');
}
add_action('admin_menu', 'line_click_tracker_admin_menu');

/* ===== 設定画面 ===== */
function line_click_tracker_settings_page() {
    if (isset($_POST['submit'])) {
        check_admin_referer('line_click_tracker_save_settings');

        // LINE: defaultモード用HTML
        $line_html = wp_kses_post($_POST['line_html']);
        update_option('line_click_tracker_button_html', $line_html);

        // LINEカスタム用URL
        $line_registration_url = esc_url_raw(sanitize_text_field($_POST['line_registration_url']));
        update_option('line_registration_url', $line_registration_url);

        // 電話番号
        $tel_number = sanitize_text_field($_POST['tel_number']);
        update_option('tel_click_tracker_phone', $tel_number);

        // 電話ボタンタイプ
        $tel_button_type = sanitize_text_field($_POST['tel_button_type']);
        update_option('tel_button_type', $tel_button_type);

        if ($tel_button_type === 'button') {
            update_option('tel_button_bg_color', sanitize_hex_color($_POST['tel_button_bg_color']));
            update_option('tel_button_text_color', sanitize_hex_color($_POST['tel_button_text_color']));
            update_option('tel_button_font_size', intval($_POST['tel_button_font_size']));
            $tel_border = sanitize_text_field($_POST['tel_button_border_radius']);
            update_option('tel_button_border_radius', ($tel_border === 'rounded' ? 'rounded' : 'square'));
            update_option('tel_button_shadow', isset($_POST['tel_button_shadow']) ? '1' : '0');
            update_option('tel_button_text', sanitize_text_field($_POST['tel_button_text']));
            // 電話ボタンフォントファミリー
            $tel_button_font_family = sanitize_text_field($_POST['tel_button_font_family']);
            update_option('tel_button_font_family', $tel_button_font_family);
        } else {
            // テキストのみ
            update_option('tel_text_custom', sanitize_text_field($_POST['tel_text_custom']));
            update_option('tel_text_color', sanitize_hex_color($_POST['tel_text_color']));
            update_option('tel_text_font_size', intval($_POST['tel_text_font_size']));
            // テキストのみのフォントファミリー
            $tel_text_font_family = sanitize_text_field($_POST['tel_text_font_family']);
            update_option('tel_text_font_family', $tel_text_font_family);
        }

        // LINEボタンデザイン
        $line_button_design = sanitize_text_field($_POST['line_button_design']);
        update_option('line_button_design', $line_button_design);

        if ($line_button_design === 'custom') {
            update_option('line_button_text', sanitize_text_field($_POST['line_button_text']));
            update_option('line_button_bg_color', sanitize_hex_color($_POST['line_button_bg_color']));
            update_option('line_button_text_color', sanitize_hex_color($_POST['line_button_text_color']));
            update_option('line_button_font_size', intval($_POST['line_button_font_size']));
            $line_border = sanitize_text_field($_POST['line_button_border_radius']);
            update_option('line_button_border_radius', ($line_border === 'rounded' ? 'rounded' : 'square'));
            update_option('line_button_shadow', isset($_POST['line_button_shadow']) ? '1' : '0');
            // LINEボタンフォントファミリー
            $line_button_font_family = sanitize_text_field($_POST['line_button_font_family']);
            update_option('line_button_font_family', $line_button_font_family);
        }

        // 通知メール
        $notification_emails = sanitize_text_field($_POST['notification_emails']);
        update_option('notification_emails', $notification_emails);

        echo '<div class="updated"><p>設定を保存しました。</p></div>';
    }

    // 既存オプションの取得
    $line_html = get_option('line_click_tracker_button_html', '');
    $line_registration_url = get_option('line_registration_url', 'https://line.me/R/ti/p/%40xxxxxx');
    $tel_number = get_option('tel_click_tracker_phone', '');

    $tel_button_type = get_option('tel_button_type', 'button');
    $tel_button_bg_color = get_option('tel_button_bg_color', '#0073aa');
    $tel_button_text_color = get_option('tel_button_text_color', '#ffffff');
    $tel_button_font_size = get_option('tel_button_font_size', '16');
    $tel_button_border_radius = get_option('tel_button_border_radius', 'rounded');
    $tel_button_shadow = get_option('tel_button_shadow', '0');
    $tel_button_text = get_option('tel_button_text', '電話する');
    $tel_button_font_family = get_option('tel_button_font_family', 'sans-serif');

    // テキストのみ
    $tel_text_custom = get_option('tel_text_custom', '電話する');
    $tel_text_color = get_option('tel_text_color', '#0073aa');
    $tel_text_font_size = get_option('tel_text_font_size', '16');
    $tel_text_font_family = get_option('tel_text_font_family', 'sans-serif');

    $line_button_design = get_option('line_button_design', 'default');
    $line_button_text = get_option('line_button_text', 'LINEで友だち追加');
    $line_button_bg_color = get_option('line_button_bg_color', '#00c300');
    $line_button_text_color = get_option('line_button_text_color', '#ffffff');
    $line_button_font_size = get_option('line_button_font_size', '16');
    $line_button_border_radius = get_option('line_button_border_radius', 'rounded');
    $line_button_shadow = get_option('line_button_shadow', '0');
    $line_button_font_family = get_option('line_button_font_family', 'sans-serif');

    $notification_emails = get_option('notification_emails', '');
    ?>
    <div class="wrap">
        <h1>クリックトラッカー設定</h1>
        <form method="post" action="">
            <?php wp_nonce_field('line_click_tracker_save_settings'); ?>

            <h2>【LINEボタン設定】</h2>
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">デザインモード</th>
                    <td>
                        <label><input type="radio" name="line_button_design" value="default" <?php checked($line_button_design, 'default'); ?>> デフォルト（HTML入力）</label>
                        <label style="margin-left:20px;"><input type="radio" name="line_button_design" value="custom" <?php checked($line_button_design, 'custom'); ?>> カスタム</label>
                    </td>
                </tr>
                <!-- default -->
                <tr class="line-default-mode" style="display: <?php echo ($line_button_design === 'default') ? 'table-row' : 'none'; ?>;">
                    <th scope="row">LINE追加ボタンHTML</th>
                    <td>
                        <textarea name="line_html" rows="5" cols="50" class="large-text code"><?php echo esc_textarea($line_html); ?></textarea>
                        <p class="description">例: &lt;a href="https://line.me/R/ti/p/%40xxxxxx"&gt;&lt;img src="..." alt="友だち追加" /&gt;&lt;/a&gt;</p>
                    </td>
                </tr>
                <!-- custom -->
                <tr class="line-custom-mode" style="display: <?php echo ($line_button_design === 'custom') ? 'table-row' : 'none'; ?>;">
                    <th scope="row">ボタンテキスト</th>
                    <td><input type="text" name="line_button_text" value="<?php echo esc_attr($line_button_text); ?>" class="regular-text" /></td>
                </tr>
                <tr class="line-custom-mode" style="display: <?php echo ($line_button_design === 'custom') ? 'table-row' : 'none'; ?>;">
                    <th scope="row">背景色</th>
                    <td><input type="color" name="line_button_bg_color" value="<?php echo esc_attr($line_button_bg_color); ?>" /></td>
                </tr>
                <tr class="line-custom-mode" style="display: <?php echo ($line_button_design === 'custom') ? 'table-row' : 'none'; ?>;">
                    <th scope="row">文字色</th>
                    <td><input type="color" name="line_button_text_color" value="<?php echo esc_attr($line_button_text_color); ?>" /></td>
                </tr>
                <tr class="line-custom-mode" style="display: <?php echo ($line_button_design === 'custom') ? 'table-row' : 'none'; ?>;">
                    <th scope="row">フォントサイズ(px)</th>
                    <td><input type="number" name="line_button_font_size" value="<?php echo esc_attr($line_button_font_size); ?>" /></td>
                </tr>
                <tr class="line-custom-mode" style="display: <?php echo ($line_button_design === 'custom') ? 'table-row' : 'none'; ?>;">
                    <th scope="row">角の形状</th>
                    <td>
                        <label><input type="radio" name="line_button_border_radius" value="square" <?php checked($line_button_border_radius, 'square'); ?>> 四角形</label>
                        <label style="margin-left:20px;"><input type="radio" name="line_button_border_radius" value="rounded" <?php checked($line_button_border_radius, 'rounded'); ?>> 丸みあり</label>
                    </td>
                </tr>
                <tr class="line-custom-mode" style="display: <?php echo ($line_button_design === 'custom') ? 'table-row' : 'none'; ?>;">
                    <th scope="row">シャドウ</th>
                    <td><label><input type="checkbox" name="line_button_shadow" <?php checked($line_button_shadow, '1'); ?>> 付ける</label></td>
                </tr>
                <tr class="line-custom-mode" style="display: <?php echo ($line_button_design === 'custom') ? 'table-row' : 'none'; ?>;">
                    <th scope="row">フォントファミリー</th>
                    <td>
                        <select name="line_button_font_family">
                            <option value="sans-serif" <?php selected($line_button_font_family, 'sans-serif'); ?>>sans-serif</option>
                            <option value="Meiryo" <?php selected($line_button_font_family, 'Meiryo'); ?>>Meiryo</option>
                            <option value="Noto Sans JP" <?php selected($line_button_font_family, 'Noto Sans JP'); ?>>Noto Sans JP</option>
                            <option value="Hiragino Kaku Gothic Pro" <?php selected($line_button_font_family, 'Hiragino Kaku Gothic Pro'); ?>>Hiragino Kaku Gothic Pro</option>
                            <option value="Yu Gothic" <?php selected($line_button_font_family, 'Yu Gothic'); ?>>Yu Gothic</option>
                        </select>
                    </td>
                </tr>
                <tr class="line-custom-mode" style="display: <?php echo ($line_button_design === 'custom') ? 'table-row' : 'none'; ?>;">
                    <th scope="row">LINE登録URL</th>
                    <td>
                        <input type="text" name="line_registration_url" value="<?php echo esc_attr($line_registration_url); ?>" class="regular-text" />
                        <p class="description">例: https://line.me/R/ti/p/%40xxxxxx</p>
                    </td>
                </tr>
            </table>

            <div style="margin:20px 0;">
                <strong>LINEボタンプレビュー:</strong><br>
                <div id="line_preview" style="margin-top:10px;"></div>
            </div>

            <h2>【電話ボタン設定】</h2>
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">電話番号</th>
                    <td>
                        <input type="text" name="tel_number" value="<?php echo esc_attr($tel_number); ?>" class="regular-text" />
                        <p class="description">例: 0123456789 （ハイフンなし）</p>
                    </td>
                </tr>
                <tr valign="top">
                    <th scope="row">ボタンタイプ</th>
                    <td>
                        <label><input type="radio" name="tel_button_type" value="text" <?php checked($tel_button_type, 'text'); ?>> テキストのみ</label>
                        <label style="margin-left:20px;"><input type="radio" name="tel_button_type" value="button" <?php checked($tel_button_type, 'button'); ?>> ボタン形式</label>
                    </td>
                </tr>
                <!-- テキストのみ -->
                <tr class="tel-text-options" style="display: <?php echo ($tel_button_type === 'text') ? 'table-row' : 'none'; ?>;">
                    <th scope="row">表示テキスト</th>
                    <td><input type="text" name="tel_text_custom" value="<?php echo esc_attr($tel_text_custom); ?>" class="regular-text" /></td>
                </tr>
                <tr class="tel-text-options" style="display: <?php echo ($tel_button_type === 'text') ? 'table-row' : 'none'; ?>;">
                    <th scope="row">文字色</th>
                    <td><input type="color" name="tel_text_color" value="<?php echo esc_attr($tel_text_color); ?>" /></td>
                </tr>
                <tr class="tel-text-options" style="display: <?php echo ($tel_button_type === 'text') ? 'table-row' : 'none'; ?>;">
                    <th scope="row">フォントサイズ(px)</th>
                    <td><input type="number" name="tel_text_font_size" value="<?php echo esc_attr($tel_text_font_size); ?>" /></td>
                </tr>
                <tr class="tel-text-options" style="display: <?php echo ($tel_button_type === 'text') ? 'table-row' : 'none'; ?>;">
                    <th scope="row">フォントファミリー</th>
                    <td>
                        <select name="tel_text_font_family">
                            <option value="sans-serif" <?php selected($tel_text_font_family, 'sans-serif'); ?>>sans-serif</option>
                            <option value="Meiryo" <?php selected($tel_text_font_family, 'Meiryo'); ?>>Meiryo</option>
                            <option value="Noto Sans JP" <?php selected($tel_text_font_family, 'Noto Sans JP'); ?>>Noto Sans JP</option>
                            <option value="Hiragino Kaku Gothic Pro" <?php selected($tel_text_font_family, 'Hiragino Kaku Gothic Pro'); ?>>Hiragino Kaku Gothic Pro</option>
                            <option value="Yu Gothic" <?php selected($tel_text_font_family, 'Yu Gothic'); ?>>Yu Gothic</option>
                        </select>
                    </td>
                </tr>
                <!-- ボタン形式 -->
                <tr class="tel-button-options" style="display: <?php echo ($tel_button_type === 'button') ? 'table-row' : 'none'; ?>;">
                    <th scope="row">背景色</th>
                    <td><input type="color" name="tel_button_bg_color" value="<?php echo esc_attr($tel_button_bg_color); ?>" /></td>
                </tr>
                <tr class="tel-button-options" style="display: <?php echo ($tel_button_type === 'button') ? 'table-row' : 'none'; ?>;">
                    <th scope="row">文字色</th>
                    <td><input type="color" name="tel_button_text_color" value="<?php echo esc_attr($tel_button_text_color); ?>" /></td>
                </tr>
                <tr class="tel-button-options" style="display: <?php echo ($tel_button_type === 'button') ? 'table-row' : 'none'; ?>;">
                    <th scope="row">フォントサイズ(px)</th>
                    <td><input type="number" name="tel_button_font_size" value="<?php echo esc_attr($tel_button_font_size); ?>" /></td>
                </tr>
                <tr class="tel-button-options" style="display: <?php echo ($tel_button_type === 'button') ? 'table-row' : 'none'; ?>;">
                    <th scope="row">角の形状</th>
                    <td>
                        <label><input type="radio" name="tel_button_border_radius" value="square" <?php checked($tel_button_border_radius, 'square'); ?>> 四角形</label>
                        <label style="margin-left:20px;"><input type="radio" name="tel_button_border_radius" value="rounded" <?php checked($tel_button_border_radius, 'rounded'); ?>> 丸みあり</label>
                    </td>
                </tr>
                <tr class="tel-button-options" style="display: <?php echo ($tel_button_type === 'button') ? 'table-row' : 'none'; ?>;">
                    <th scope="row">シャドウ</th>
                    <td><label><input type="checkbox" name="tel_button_shadow" <?php checked($tel_button_shadow, '1'); ?>> 付ける</label></td>
                </tr>
                <tr class="tel-button-options" style="display: <?php echo ($tel_button_type === 'button') ? 'table-row' : 'none'; ?>;">
                    <th scope="row">ボタンテキスト</th>
                    <td><input type="text" name="tel_button_text" value="<?php echo esc_attr($tel_button_text); ?>" class="regular-text" /></td>
                </tr>
                <tr class="tel-button-options" style="display: <?php echo ($tel_button_type === 'button') ? 'table-row' : 'none'; ?>;">
                    <th scope="row">フォントファミリー</th>
                    <td>
                        <select name="tel_button_font_family">
                            <option value="sans-serif" <?php selected($tel_button_font_family, 'sans-serif'); ?>>sans-serif</option>
                            <option value="Meiryo" <?php selected($tel_button_font_family, 'Meiryo'); ?>>Meiryo</option>
                            <option value="Noto Sans JP" <?php selected($tel_button_font_family, 'Noto Sans JP'); ?>>Noto Sans JP</option>
                            <option value="Hiragino Kaku Gothic Pro" <?php selected($tel_button_font_family, 'Hiragino Kaku Gothic Pro'); ?>>Hiragino Kaku Gothic Pro</option>
                            <option value="Yu Gothic" <?php selected($tel_button_font_family, 'Yu Gothic'); ?>>Yu Gothic</option>
                        </select>
                    </td>
                </tr>
            </table>

            <div style="margin:20px 0;">
                <strong>電話ボタンプレビュー:</strong><br>
                <div id="tel_preview" style="margin-top:10px;"></div>
            </div>

            <h2>【通知設定】</h2>
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">通知メールアドレス</th>
                    <td>
                        <input type="text" name="notification_emails" value="<?php echo esc_attr($notification_emails); ?>" class="regular-text" />
                        <p class="description">クリック通知を送信するメールアドレスをカンマ区切りで入力してください。</p>
                    </td>
                </tr>
            </table>

            <?php submit_button('変更を保存'); ?>
        </form>

        <!-- 使用するショートコード表示 -->
        <div class="notice notice-info" style="margin-top:20px;">
            <p><strong>使用するショートコード:</strong></p>
            <p>LINEボタン用: <code>[line_add_button]</code></p>
            <p>電話番号リンク用: <code>[tel_click]</code></p>
        </div>
    </div>
    <script>
    (function($){
        // LINEボタンプレビュー更新
        function updateLinePreview(){
            var design = $('input[name="line_button_design"]:checked').val();
            if(design=='default'){
                var html = $('textarea[name="line_html"]').val();
                $('#line_preview').html(html);
            } else {
                var text = $('input[name="line_button_text"]').val();
                var bg = $('input[name="line_button_bg_color"]').val();
                var color = $('input[name="line_button_text_color"]').val();
                var size = $('input[name="line_button_font_size"]').val();
                var border = $('input[name="line_button_border_radius"]:checked').val();
                var borderRadius = (border=='rounded') ? '10px' : '0px';
                var shadow = ($('input[name="line_button_shadow"]').is(':checked')) ? '2px 2px 5px rgba(0,0,0,0.3)' : 'none';
                var font = $('select[name="line_button_font_family"]').val() || 'sans-serif';
                var url = $('input[name="line_registration_url"]').val();
                if(!url) url = 'https://line.me';
                var tracking_url = '<?php echo esc_url(home_url('/')); ?>' + '?line_click=1&redirect_url=' + encodeURIComponent(url);
                var style = 'background-color:'+bg+'; color:'+color+'; font-size:'+size+'px; padding:10px 20px; border:none; border-radius:'+borderRadius+'; box-shadow:'+shadow+'; text-decoration:none; display:inline-block; font-family:"'+font+'", sans-serif;';
                var html = '<a href="'+tracking_url+'" style="'+style+'">'+text+'</a>';
                $('#line_preview').html(html);
            }
        }
        // 電話ボタンプレビュー更新
        function updateTelPreview(){
            var type = $('input[name="tel_button_type"]:checked').val();
            var tracking_url = '<?php echo esc_url(home_url('/')); ?>' + '?tel_click=1&redirect_url=' + encodeURIComponent('tel:' + <?php echo json_encode(get_option('tel_click_tracker_phone', '')); ?>);
            if(type=='text'){
                var text = $('input[name="tel_text_custom"]').val() || '電話する';
                var color = $('input[name="tel_text_color"]').val();
                var size = $('input[name="tel_text_font_size"]').val();
                var font = $('select[name="tel_text_font_family"]').val() || 'sans-serif';
                var style = 'color:'+color+'; font-size:'+size+'px; font-family:"'+font+'", sans-serif; text-decoration:none;';
                $('#tel_preview').html('<a href="'+tracking_url+'" style="'+style+'">'+text+'</a>');
            } else {
                var text = $('input[name="tel_button_text"]').val() || '電話する';
                var bg = $('input[name="tel_button_bg_color"]').val();
                var color = $('input[name="tel_button_text_color"]').val();
                var size = $('input[name="tel_button_font_size"]').val();
                var border = $('input[name="tel_button_border_radius"]:checked').val();
                var borderRadius = (border=='rounded') ? '10px' : '0px';
                var shadow = ($('input[name="tel_button_shadow"]').is(':checked')) ? '2px 2px 5px rgba(0,0,0,0.3)' : 'none';
                var font2 = $('select[name="tel_button_font_family"]').val() || 'sans-serif';
                var style = 'background-color:'+bg+'; color:'+color+'; font-size:'+size+'px; padding:10px 20px; border:none; border-radius:'+borderRadius+'; box-shadow:'+shadow+'; text-decoration:none; display:inline-block; font-family:"'+font2+'", sans-serif;';
                var html = '<a href="'+tracking_url+'" style="'+style+'">'+text+'</a>';
                $('#tel_preview').html(html);
            }
        }

        updateLinePreview();
        updateTelPreview();

        // イベントハンドラ
        $('input[name="line_button_design"], textarea[name="line_html"], input[name="line_button_text"], input[name="line_button_bg_color"], input[name="line_button_text_color"], input[name="line_button_font_size"], input[name="line_button_border_radius"], input[name="line_button_shadow"], select[name="line_button_font_family"], input[name="line_registration_url"]').on('change keyup', updateLinePreview);

        $('input[name="tel_button_type"]').on('change', function(){
            if($(this).val()=='button'){
                $('.tel-button-options').show();
                $('.tel-text-options').hide();
            } else {
                $('.tel-button-options').hide();
                $('.tel-text-options').show();
            }
            updateTelPreview();
        });
        $('input[name="tel_button_bg_color"], input[name="tel_button_text_color"], input[name="tel_button_font_size"], input[name="tel_button_border_radius"], input[name="tel_button_shadow"], input[name="tel_button_text"], select[name="tel_button_font_family"]').on('change keyup', updateTelPreview);
        $('input[name="tel_text_custom"], input[name="tel_text_color"], input[name="tel_text_font_size"], select[name="tel_text_font_family"]').on('change keyup', updateTelPreview);

        $('input[name="line_button_design"]').on('change', function(){
            if($(this).val()=='default'){
                $('.line-default-mode').show();
                $('.line-custom-mode').hide();
            } else {
                $('.line-default-mode').hide();
                $('.line-custom-mode').show();
            }
            updateLinePreview();
        });
    })(jQuery);
    </script>
    <style>
      #line_preview a, #tel_preview a {
          margin-top:10px;
      }
    </style>
    <?php
}

/* ===== ログ一覧画面（管理画面UI 改善） ===== */
function line_click_tracker_logs_page() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'line_click_logs';
    $filter = isset($_GET['filter']) ? sanitize_text_field($_GET['filter']) : 'all';

    // 選択削除処理
    if (isset($_POST['delete_selected_logs'])) {
        check_admin_referer('line_click_tracker_delete_selected_logs');
        if (isset($_POST['log_ids']) && is_array($_POST['log_ids'])) {
            $ids = array_map('intval', $_POST['log_ids']);
            if (!empty($ids)) {
                $ids_str = implode(',', $ids);
                $wpdb->query("DELETE FROM $table_name WHERE id IN ($ids_str)");
                echo '<div class="updated"><p>選択したログを削除しました。</p></div>';
            }
        }
    }

    // 全ログ削除処理
    if (isset($_GET['action']) && $_GET['action'] === 'delete_all') {
        if (check_admin_referer('line_click_tracker_delete_all')) {
            $wpdb->query("TRUNCATE TABLE $table_name");
            echo '<div class="updated"><p>全ログを削除しました。</p></div>';
        } else {
            echo '<div class="error"><p>不正なリクエストです。</p></div>';
        }
    }

    $query = "SELECT * FROM $table_name";
    if ($filter !== 'all') {
        $query .= " WHERE click_type = '" . esc_sql($filter) . "'";
    }
    $query .= " ORDER BY click_time DESC";
    $results = $wpdb->get_results($query);
    ?>
    <div class="wrap" style="font-family: sans-serif;">
        <h1 style="border-bottom: 2px solid #ccc; padding-bottom: 10px;">クリックログ</h1>

        <style>
          /* ログ一覧テーブルのカスタムCSS */
          .wp-list-table {
              width: 100%;
              border-collapse: collapse;
              table-layout: fixed; /* カラム幅固定レイアウト */
          }
          .wp-list-table th {
              background-color: #f7f7f7;
              border-bottom: 2px solid #ccc;
              padding: 10px;
              text-align: left;
              white-space: nowrap; /* ヘッダの崩れを防ぐ */
          }
          .wp-list-table td {
              border-bottom: 1px solid #eee;
              padding: 10px;
              word-wrap: break-word;
              overflow-wrap: break-word;
              word-break: break-word;
              white-space: pre-wrap;
          }
          .wp-list-table tr:hover {
              background-color: #f1f1f1;
          }

          /* 1列目（選択）を小さめにする */
          .wp-list-table th:nth-child(1),
          .wp-list-table td:nth-child(1) {
              width: 3%;
              text-align: center;
          }
          .wp-list-table th:nth-child(2),
          .wp-list-table td:nth-child(2) { width: 5%; }
          .wp-list-table th:nth-child(3),
          .wp-list-table td:nth-child(3) { width: 10%; }
          .wp-list-table th:nth-child(4),
          .wp-list-table td:nth-child(4) { width: 5%; }
          .wp-list-table th:nth-child(5),
          .wp-list-table td:nth-child(5) { width: 15%; }
          .wp-list-table th:nth-child(6),
          .wp-list-table td:nth-child(6) { width: 15%; }
          .wp-list-table th:nth-child(7),
          .wp-list-table td:nth-child(7) { width: 10%; }
          .wp-list-table th:nth-child(8),
          .wp-list-table td:nth-child(8) { width: 10%; }
          .wp-list-table th:nth-child(9),
          .wp-list-table td:nth-child(9) { width: 15%; }
          .wp-list-table th:nth-child(10),
          .wp-list-table td:nth-child(10) { width: 5%; }
          .wp-list-table th:nth-child(11),
          .wp-list-table td:nth-child(11) { width: 5%; }
          .wp-list-table th:nth-child(12),
          .wp-list-table td:nth-child(12) { width: 10%; }
        </style>

        <form method="get" action="">
            <input type="hidden" name="page" value="line-click-tracker-logs">
            <label for="filter">フィルタ:</label>
            <select name="filter" id="filter" onchange="this.form.submit()">
                <option value="all" <?php selected($filter, 'all'); ?>>すべて</option>
                <option value="line" <?php selected($filter, 'line'); ?>>LINE</option>
                <option value="tel" <?php selected($filter, 'tel'); ?>>電話</option>
            </select>
        </form>

        <p>
            <a href="<?php echo esc_url(wp_nonce_url(admin_url('admin.php?page=line-click-tracker-logs&action=delete_all&filter=' . $filter), 'line_click_tracker_delete_all')); ?>"
               onclick="return confirm('本当に全てのログを削除してもよろしいですか？');"
               class="button button-secondary">
               全ログ削除
            </a>
        </p>

        <form method="post" action="">
            <?php wp_nonce_field('line_click_tracker_delete_selected_logs'); ?>
            <table class="wp-list-table">
                <thead>
                    <tr>
                        <th>選択</th>
                        <th>ID</th>
                        <th>クリック日時</th>
                        <th>クリックタイプ</th>
                        <th>ページURL</th>
                        <th>リファラー</th>
                        <th>IPアドレス</th>
                        <th>地域</th>
                        <th>ユーザーエージェント</th>
                        <th>端末</th>
                        <th>訪問回数</th>
                        <th>訪問履歴</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if($results) : ?>
                        <?php foreach($results as $row): ?>
                            <tr>
                                <td><input type="checkbox" name="log_ids[]" value="<?php echo esc_attr($row->id); ?>"></td>
                                <td><?php echo esc_html($row->id); ?></td>
                                <td><?php echo esc_html($row->click_time); ?></td>
                                <td><?php echo esc_html($row->click_type); ?></td>
                                <td><?php echo esc_html($row->page_url); ?></td>
                                <td><?php echo esc_html($row->referrer); ?></td>
                                <td><?php echo esc_html($row->ip_address); ?></td>
                                <td><?php echo esc_html($row->region); ?></td>
                                <td><?php echo esc_html($row->user_agent); ?></td>
                                <td><?php echo esc_html($row->device); ?></td>
                                <td><?php echo esc_html($row->visit_count); ?></td>
                                <td><?php echo esc_html($row->visit_history); ?></td>
                            </tr>
                        <?php endforeach; ?>
                    <?php else: ?>
                        <tr><td colspan="12">ログがありません。</td></tr>
                    <?php endif; ?>
                </tbody>
            </table>
            <p>
                <input type="submit" name="delete_selected_logs" class="button button-secondary"
                       value="選択したログを削除"
                       onclick="return confirm('選択したログを削除してもよろしいですか？');">
            </p>
        </form>
    </div>
    <?php
}

/* ===== ショートコード [line_add_button] ===== */
function line_click_tracker_shortcode($atts) {
    $line_button_design = get_option('line_button_design', 'default');
    if($line_button_design == 'default'){
        // defaultモード: 管理画面で登録したHTMLをそのまま使い、hrefだけトラッキングURLに差し替え
        $line_html = get_option('line_click_tracker_button_html', '');
        if(!$line_html) return '';
        $pattern = '/href=["\']([^"\']+)["\']/';
        if(preg_match($pattern, $line_html, $matches)){
            $original_url = $matches[1];
            $tracking_url = esc_url(home_url('/')) . '?line_click=1&redirect_url=' . urlencode($original_url);
            $line_html = preg_replace($pattern, 'href="' . $tracking_url . '"', $line_html);
        }
        return $line_html;
    } else {
        // customモード: カスタムデザイン
        $line_button_text = get_option('line_button_text', 'LINEで友だち追加');
        $bg_color = get_option('line_button_bg_color', '#00c300');
        $text_color = get_option('line_button_text_color', '#ffffff');
        $font_size = get_option('line_button_font_size', '16');
        $border = get_option('line_button_border_radius', 'rounded') === 'rounded' ? '10px' : '0px';
        $shadow = get_option('line_button_shadow', '0') === '1' ? '2px 2px 5px rgba(0,0,0,0.3)' : 'none';
        $line_button_font_family = get_option('line_button_font_family', 'sans-serif');
        $original_url = get_option('line_registration_url', 'https://line.me');
        $tracking_url = esc_url(home_url('/')) . '?line_click=1&redirect_url=' . urlencode($original_url);

        $style = "background-color: {$bg_color}; color: {$text_color}; font-size: {$font_size}px; padding:10px 20px; border:none; border-radius: {$border}; box-shadow: {$shadow}; text-decoration:none; display:inline-block; font-family: \"{$line_button_font_family}\", sans-serif;";

        return '<a href="'.esc_url($tracking_url).'" style="'.esc_attr($style).'">'.esc_html($line_button_text).'</a>';
    }
}
add_shortcode('line_add_button', 'line_click_tracker_shortcode');

/* ===== ショートコード [tel_click] ===== */
function tel_click_tracker_shortcode($atts) {
    $tel_number = get_option('tel_click_tracker_phone', '');
    if(!$tel_number) return '';
    $redirect_url = 'tel:' . $tel_number;
    $tracking_url = esc_url(home_url('/')) . '?tel_click=1&redirect_url=' . urlencode($redirect_url);
    $type = get_option('tel_button_type', 'button');

    if($type=='text'){
        // テキストのみ
        $text = get_option('tel_text_custom', '電話する');
        $text_color = get_option('tel_text_color', '#0073aa');
        $font_size = get_option('tel_text_font_size', '16');
        $tel_text_font_family = get_option('tel_text_font_family', 'sans-serif');
        $style = "color: {$text_color}; font-size: {$font_size}px; text-decoration:none; font-family: \"{$tel_text_font_family}\", sans-serif;";
        return '<a href="'.esc_url($tracking_url).'" style="'.esc_attr($style).'">'.esc_html($text).'</a>';
    } else {
        // ボタン形式
        $bg_color = get_option('tel_button_bg_color', '#0073aa');
        $text_color = get_option('tel_button_text_color', '#ffffff');
        $font_size = get_option('tel_button_font_size', '16');
        $border = get_option('tel_button_border_radius', 'rounded') === 'rounded' ? '10px' : '0px';
        $shadow = get_option('tel_button_shadow', '0') === '1' ? '2px 2px 5px rgba(0,0,0,0.3)' : 'none';
        $tel_button_font_family = get_option('tel_button_font_family', 'sans-serif');
        $text = get_option('tel_button_text', '電話する');

        $style = "background-color: {$bg_color}; color: {$text_color}; font-size: {$font_size}px; padding:10px 20px; border:none; border-radius: {$border}; box-shadow: {$shadow}; text-decoration:none; display:inline-block; font-family: \"{$tel_button_font_family}\", sans-serif;";

        return '<a href="'.esc_url($tracking_url).'" style="'.esc_attr($style).'">'.esc_html($text).'</a>';
    }
}
add_shortcode('tel_click', 'tel_click_tracker_shortcode');

/* ===== LINEクリック処理 ===== */
function line_click_tracker_handle_click() {
    if (isset($_GET['line_click']) && $_GET['line_click'] == 1) {
        global $wpdb;
        $table_name = $wpdb->prefix . 'line_click_logs';

        $click_time  = current_time('mysql');
        $page_url    = isset($_SERVER['HTTP_REFERER']) ? esc_url_raw($_SERVER['HTTP_REFERER']) : '';
        $referrer    = isset($_SERVER['HTTP_REFERER']) ? esc_url_raw($_SERVER['HTTP_REFERER']) : '';
        $ip_address  = $_SERVER['REMOTE_ADDR'];
        $user_agent  = $_SERVER['HTTP_USER_AGENT'];
        $device      = (strpos($user_agent, 'Mobile') !== false) ? 'スマホ' : 'PC';

        $visit_count = isset($_COOKIE['line_visit_count']) ? intval($_COOKIE['line_visit_count']) + 1 : 1;
        setcookie('line_visit_count', $visit_count, time() + 3600*24*30, COOKIEPATH, COOKIE_DOMAIN);

        $visit_history = isset($_COOKIE['line_visit_history']) ? sanitize_text_field($_COOKIE['line_visit_history']) : '';

        // IP -> 地域
        $region = '';
        $geo_response = @file_get_contents("http://ip-api.com/json/{$ip_address}?fields=city");
        if ($geo_response) {
            $geo_data = json_decode($geo_response);
            if ($geo_data && isset($geo_data->city)) {
                $region = $geo_data->city;
            }
        }

        // DB記録
        $wpdb->insert($table_name, array(
            'click_time'    => $click_time,
            'click_type'    => 'line',
            'page_url'      => $page_url,
            'referrer'      => $referrer,
            'ip_address'    => $ip_address,
            'region'        => $region,
            'user_agent'    => $user_agent,
            'device'        => $device,
            'visit_count'   => $visit_count,
            'visit_history' => $visit_history,
        ));

        // 通知メール送信
        $notification_emails = get_option('notification_emails', '');
        if (!empty($notification_emails)) {
            $emails = array_map('trim', explode(',', $notification_emails));
            $subject = "[クリック通知] LINEクリック発生";
            $message = "日時: $click_time\nIP: $ip_address\nユーザーエージェント: $user_agent\nページURL: $page_url\nリファラー: $referrer\n地域: $region";
            wp_mail($emails, $subject, $message);
        }

        // リダイレクト
        $redirect_url = home_url('/');
        if (isset($_GET['redirect_url'])) {
            $redirect_url = esc_url_raw(urldecode($_GET['redirect_url']));
        }
        wp_redirect($redirect_url);
        exit;
    }
}
add_action('init', 'line_click_tracker_handle_click');

/* ===== 電話クリック処理 ===== */
function tel_click_tracker_handle_click() {
    if (isset($_GET['tel_click']) && $_GET['tel_click'] == 1) {
        global $wpdb;
        $table_name = $wpdb->prefix . 'line_click_logs';

        $click_time  = current_time('mysql');
        $page_url    = isset($_SERVER['HTTP_REFERER']) ? esc_url_raw($_SERVER['HTTP_REFERER']) : '';
        $referrer    = isset($_SERVER['HTTP_REFERER']) ? esc_url_raw($_SERVER['HTTP_REFERER']) : '';
        $ip_address  = $_SERVER['REMOTE_ADDR'];
        $user_agent  = $_SERVER['HTTP_USER_AGENT'];
        $device      = (strpos($user_agent, 'Mobile') !== false) ? 'スマホ' : 'PC';

        $visit_count = isset($_COOKIE['line_visit_count']) ? intval($_COOKIE['line_visit_count']) + 1 : 1;
        setcookie('line_visit_count', $visit_count, time() + 3600*24*30, COOKIEPATH, COOKIE_DOMAIN);

        $visit_history = isset($_COOKIE['line_visit_history']) ? sanitize_text_field($_COOKIE['line_visit_history']) : '';

        // IP -> 地域
        $region = '';
        $geo_response = @file_get_contents("http://ip-api.com/json/{$ip_address}?fields=city");
        if ($geo_response) {
            $geo_data = json_decode($geo_response);
            if ($geo_data && isset($geo_data->city)) {
                $region = $geo_data->city;
            }
        }

        // DB記録
        $wpdb->insert($table_name, array(
            'click_time'    => $click_time,
            'click_type'    => 'tel',
            'page_url'      => $page_url,
            'referrer'      => $referrer,
            'ip_address'    => $ip_address,
            'region'        => $region,
            'user_agent'    => $user_agent,
            'device'        => $device,
            'visit_count'   => $visit_count,
            'visit_history' => $visit_history,
        ));

        // 通知メール送信
        $notification_emails = get_option('notification_emails', '');
        if (!empty($notification_emails)) {
            $emails = array_map('trim', explode(',', $notification_emails));
            $subject = "[クリック通知] 電話クリック発生";
            $message = "日時: $click_time\nIP: $ip_address\nユーザーエージェント: $user_agent\nページURL: $page_url\nリファラー: $referrer\n地域: $region";
            wp_mail($emails, $subject, $message);
        }

        // リダイレクト
        $redirect_url = home_url('/');
        if (isset($_GET['redirect_url'])) {
            $redirect_url = esc_url_raw(urldecode($_GET['redirect_url']));
        }
        wp_redirect($redirect_url);
        exit;
    }
}
add_action('init', 'tel_click_tracker_handle_click');

/* ===== フロント側JS ===== */
function line_click_tracker_enqueue_script() {
    if (!is_admin()) {
        ?>
        <script type="text/javascript">
        (function(){
            var history = sessionStorage.getItem('line_visit_history') || '';
            var currentPage = window.location.pathname;
            history = history ? history + ' > ' + currentPage : currentPage;
            sessionStorage.setItem('line_visit_history', history);
            document.cookie = "line_visit_history=" + encodeURIComponent(history) + "; path=/";

            document.addEventListener('DOMContentLoaded', function(){
                // LINEボタンのGA4イベント
                var lineButtons = document.querySelectorAll('a[href*="?line_click=1"]');
                lineButtons.forEach(function(btn){
                    btn.addEventListener('click', function(e){
                        if (typeof gtag !== 'undefined') {
                            gtag('event', 'line_click_plugin', {
                                'event_category': 'Line',
                                'event_label': 'Line Button Click'
                            });
                        }
                    });
                });
                // 電話ボタンのGA4イベント
                var telButtons = document.querySelectorAll('a[href*="?tel_click=1"]');
                telButtons.forEach(function(btn){
                    btn.addEventListener('click', function(e){
                        if (typeof gtag !== 'undefined') {
                            gtag('event', 'tel_click_plugin', {
                                'event_category': 'Tel',
                                'event_label': 'Tel Button Click'
                            });
                        }
                    });
                });
            });
        })();
        </script>
        <?php
    }
}
add_action('wp_footer', 'line_click_tracker_enqueue_script');
?>
